@@ -5,19 +5,21 @@
  */
 
 #include <QApplication>
-#include <QQmlApplicationEngine>
 #include <QCommandLineParser>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QLoggingCategory>
+#include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QWindow>
-#include <QLoggingCategory>
 
-#include <KDeclarative/KDeclarative>
-#include <KDBusService>
-#include <KLocalizedString>
 #include <KAboutData>
+#include <KDBusService>
+#include <KDeclarative/KDeclarative>
+#include <KLocalizedString>
 
-#include "ToolsModel.h"
 #include "Configuration.h"
+#include "ToolsModel.h"
 
 static QLoggingCategory::CategoryFilter oldCategoryFilter;
 
@@ -73,16 +75,14 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain("plasma-systemmonitor");
 
-    KAboutData aboutData{
-        /* componentName */ "plasma-systemmonitor",
-        /* displayName */ i18n("System Monitor"),
-        /* version */ "1.0",
-        /* shortDescription */ i18n("An application for monitoring system resources"),
-        /* licenseType */ KAboutLicense::GPL,
-        /* copyrightStatement */ i18n("© 2020 Plasma Development Team"),
-        /* otherText */ QString{},
-        /* homePageAddress */ QString{}
-    };
+    KAboutData aboutData{/* componentName */ "plasma-systemmonitor",
+                         /* displayName */ i18n("System Monitor"),
+                         /* version */ PROJECT_VERSION,
+                         /* shortDescription */ i18n("An application for monitoring system resources"),
+                         /* licenseType */ KAboutLicense::GPL,
+                         /* copyrightStatement */ i18n("© 2020 Plasma Development Team"),
+                         /* otherText */ QString{},
+                         /* homePageAddress */ QString{}};
     aboutData.setDesktopFileName(QStringLiteral("org.kde.plasma-systemmonitor"));
     aboutData.setProgramLogo(app.windowIcon());
 
@@ -94,10 +94,7 @@ int main(int argc, char **argv)
     aboutData.addAuthor(i18n("Marco Martin"), i18n("Development"), QString{});
     aboutData.addAuthor(i18n("David Edmundson"), i18n("Development"), QString{});
 
-    aboutData.setTranslator(
-        i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"),
-        i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails")
-    );
+    aboutData.setTranslator(i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"), i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
 
     KAboutData::setApplicationData(aboutData);
 
@@ -113,15 +110,13 @@ int main(int argc, char **argv)
     qmlRegisterAnonymousType<QAbstractItemModel>("org.kde.systemmonitor", 1);
     qmlRegisterType<ToolsModel>("org.kde.systemmonitor", 1, 0, "ToolsModel");
     qmlRegisterType<Configuration>("org.kde.systemmonitor", 1, 0, "Configuration");
-    qmlRegisterSingletonType<CommandLineArguments>("org.kde.systemmonitor", 1, 0, "CommandLineArguments", [&parser](QQmlEngine*, QJSEngine*) {
+    qmlRegisterSingletonType<CommandLineArguments>("org.kde.systemmonitor", 1, 0, "CommandLineArguments", [&parser](QQmlEngine *, QJSEngine *) {
         return new CommandLineArguments{parser};
     });
 
     QQmlApplicationEngine engine;
 
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(&engine);
-    kdeclarative.setupContext();
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
     engine.load(QStringLiteral(":/main.qml"));
 
@@ -132,7 +127,9 @@ int main(int argc, char **argv)
             win->requestActivate();
         }
     });
-
+    // QDBusConnectionInterface::StartService is blocking so we do it manually
+    const auto busInterface = QDBusConnection::sessionBus().interface();
+    busInterface->asyncCall(QStringLiteral("StartServiceByName"), QStringLiteral("org.kde.ksystemstats"), 0u);
     return app.exec();
 }
 
