@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
- * 
+ *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
@@ -12,7 +12,7 @@
 
 using namespace KSysGuard;
 
-ProcessSortFilterModel::ProcessSortFilterModel(QObject* parent)
+ProcessSortFilterModel::ProcessSortFilterModel(QObject *parent)
     : QSortFilterProxyModel(parent)
 {
     setSortRole(ProcessDataModel::Value);
@@ -24,7 +24,7 @@ ProcessSortFilterModel::ProcessSortFilterModel(QObject* parent)
     setRecursiveFilteringEnabled(true);
 }
 
-void ProcessSortFilterModel::setSourceModel(QAbstractItemModel* newSourceModel)
+void ProcessSortFilterModel::setSourceModel(QAbstractItemModel *newSourceModel)
 {
     auto oldSourceModel = sourceModel();
 
@@ -42,11 +42,17 @@ void ProcessSortFilterModel::setSourceModel(QAbstractItemModel* newSourceModel)
         connect(newSourceModel, &QAbstractItemModel::columnsInserted, this, &ProcessSortFilterModel::findColumns);
         connect(newSourceModel, &QAbstractItemModel::columnsRemoved, this, &ProcessSortFilterModel::findColumns);
         connect(newSourceModel, &QAbstractItemModel::columnsMoved, this, &ProcessSortFilterModel::findColumns);
+        findColumns();
     }
 }
 
-bool ProcessSortFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
+bool ProcessSortFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
+    // not handled a reset yet, we'll invalidate at the end of modelReset anyway
+    if (m_uidColumn == -1) {
+        return false;
+    }
+
     auto result = true;
 
     auto source = sourceModel();
@@ -55,17 +61,17 @@ bool ProcessSortFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex&
         auto uid = source->data(source->index(sourceRow, m_uidColumn, sourceParent), ProcessDataModel::Value).toUInt();
 
         switch (m_viewMode) {
-            case ViewOwn:
-                result = m_currentUser.userId().nativeId() == uid;
-                break;
-            case ViewUser:
-                result = uid >= 1000 && uid < 65534;
-                break;
-            case ViewSystem:
-                result = uid < 1000 || uid >= 65534;
-                break;
-            default:
-                break;
+        case ViewOwn:
+            result = m_currentUser.userId().nativeId() == uid;
+            break;
+        case ViewUser:
+            result = uid >= 1000 && uid < 65534;
+            break;
+        case ViewSystem:
+            result = uid < 1000 || uid >= 65534;
+            break;
+        default:
+            break;
         }
     }
 
@@ -78,22 +84,10 @@ bool ProcessSortFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex&
         result = QSortFilterProxyModel::filterAcceptsRow(sourceRow, sourceParent);
     }
 
-    // We are recursive, if a descendant is accepted, also the ancestors are
-    if (!result) {
-        const QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
-        const int count = sourceModel()->rowCount(index);
-
-        for (int i = 0; i < count; ++i) {
-            if (filterAcceptsRow(i, index)) {
-                return true;
-            }
-        }
-    }
-
     return result;
 }
 
-bool ProcessSortFilterModel::filterAcceptsColumn(int sourceColumn, const QModelIndex& sourceParent) const
+bool ProcessSortFilterModel::filterAcceptsColumn(int sourceColumn, const QModelIndex &sourceParent) const
 {
     Q_UNUSED(sourceParent)
 
@@ -110,7 +104,7 @@ QString ProcessSortFilterModel::filterString() const
     return m_filterString;
 }
 
-void ProcessSortFilterModel::setFilterString(const QString & newFilterString)
+void ProcessSortFilterModel::setFilterString(const QString &newFilterString)
 {
     if (newFilterString == m_filterString) {
         return;
@@ -193,5 +187,5 @@ void ProcessSortFilterModel::findColumns()
         }
     }
 
-    invalidate();
+    invalidateFilter();
 }
